@@ -8,7 +8,7 @@ use Archive::Har::Entry::Response();
 use Archive::Har::Entry::Cache();
 use Archive::Har::Entry::Timings();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub _DOES_NOT_APPLY { return -1 }
 
@@ -203,6 +203,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -248,13 +250,14 @@ sub TO_JSON {
 
 1;
 __END__
+
 =head1 NAME
 
 Archive::Har::Entry - Represents a single http request/response pair inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR pageref IP DNS perldoc CPAN AnnoCPAN 
 
