@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Cache::Request();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -84,6 +84,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -121,13 +123,14 @@ sub TO_JSON {
 
 1;
 __END__
+
 =head1 NAME
 
 Archive::Har::Entry::Cache - Represents the cache for a single request/response pair inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR
 
