@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -115,6 +115,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -151,13 +153,14 @@ sub TO_JSON {
 
 1;
 __END__
+
 =head1 NAME
 
 Archive::Har::Entry::Cache::Request - Represents a cache request for a cache inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR etag
 
