@@ -8,7 +8,7 @@ use Archive::Har::Entry::Cookie();
 use Archive::Har::Entry::Request::QueryString();
 use Archive::Har::Entry::Request::PostData();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub _DOES_NOT_APPLY { return -1 }
 
@@ -222,6 +222,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -271,13 +273,14 @@ sub TO_JSON {
 
 1;
 __END__
+
 =head1 NAME
 
 Archive::Har::Entry::Request - Represents a single http request inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR url http undef postData CRLF
 
