@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Request::PostData::Params();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -100,6 +100,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -137,7 +139,7 @@ Archive::Har::Entry::Request::PostData - Represents a single name/value pair fro
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR PostData undef params
 
