@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -89,6 +89,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -129,7 +131,7 @@ Archive::Har::Entry::Request::PostData::Params - Represents a single name/value
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR PostData Params
 
