@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -65,6 +65,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -95,13 +97,14 @@ sub TO_JSON {
 
 1;
 __DATA__
+
 =head1 NAME
 
 Archive::Har::Entry::Request::QueryString - Represents a single name/value pair from the query string for a request inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR QueryString
 
