@@ -7,7 +7,7 @@ use Archive::Har::Entry::Header();
 use Archive::Har::Entry::Cookie();
 use Archive::Har::Entry::Response::Content();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub _DOES_NOT_APPLY { return -1 }
 
@@ -194,6 +194,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -240,13 +242,14 @@ sub TO_JSON {
 
 1;
 __END__
+
 =head1 NAME
 
 Archive::Har::Entry::Response - Represents a single http response inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR http CRLF
 
