@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Cache::Request();
 
-our $VERSION = 0.19;
+our $VERSION = '0.20';
 
 sub _DOES_NOT_APPLY { return -1 }
 
@@ -166,6 +166,8 @@ sub AUTOLOAD {
             $self->{$name} = $new;
         }
     }
+    elsif ( $name eq 'DESTROY' ) {
+    }
     else {
         Carp::croak(
 "$name is not specified in the HAR 1.2 spec and does not start with an underscore"
@@ -219,13 +221,14 @@ sub TO_JSON {
 
 1;
 __END__
+
 =head1 NAME
 
 Archive::Har::Entry::Timings - Represents the timings for the individual phases during a request/response pair inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.19
+Version '0.20'
 
 =for stopwords HAR undef dns DNS TCP ssl
 
